import csv
import numpy as np
import os
import sys
import dnn
import tflearn
from PIL import Image, ImageDraw

def read_file(filename):
	data = []
	with open(filename, "r") as file:
		reader = csv.reader(file, delimiter=",")
		next(reader) # Header ueberspringen
		for row in reader:
			row.pop(0) # Benutzernamen entfernen
			row = map(float, row)
			data.append(row)
	return data

def calculate_correlation_matrix(data):
	with np.errstate(invalid="ignore"):
		return np.corrcoef(data, rowvar=0)

def draw_matrix(matrix, filename, size=20):
	n = len(matrix)
	
	img = Image.new("RGB", (n*size, n*size))
	draw = ImageDraw.Draw(img)
	
	for i in range(0, n):
		for j in range(0, n):
			color = "hsl(0, 0%%, %d%%)" % (matrix[i][j]*100)
			draw.rectangle((i*size, j*size, (i+1)*size, (j+1)*size), fill=color)
	
	img.save(filename)

if __name__ == "__main__":
	if len(sys.argv) < 2:
		sys.exit("Usage: python correlation.py <input-csv-file>")
	
	input_file = sys.argv[1]
	
	data = read_file(input_file)
	matrix = calculate_correlation_matrix(data)
	draw_matrix(np.absolute(matrix), "correlation.png")
	
	print(matrix)
